![Buildtest](https://github.com/software-students-fall2022/python-package-exercise-project-3-team-13/actions/workflows/build.yaml/badge.svg)

[![Open in Visual Studio Code](https://classroom.github.com/assets/open-in-vscode-c66648af7eb3fe8bc4f294546bfd86ef473780cde1dea487d3c4ff354943c9ae.svg)](https://classroom.github.com/online_ide?assignment_repo_id=9088681&assignment_repo_type=AssignmentRepo)
# Python Package Exercise

A little exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

# Team Members

Kedan Zha

Bruce wu

Evan Huang

Amaan Khwaja

# Project Description

Hackertype lets you pretend you are the elite hacker you always you knew you were in your heart of hearts.

## Hackertype

Run `hackertype <language>` to run the classic hackertype program from the old internet days. Press keys to generate programming snippets from the given language and press `esc` to finish. Currently supported languages are `python` and `java`.

## Penetrate

Run `penetrate <language> <text:optional>` to simulate a penetration hack. The program will display your text in a scary looking font before launching into hackertype of your given language. The supported language and usage is the same as hackertype. When done, the program will tell you that you are logging out.

Happy hacking!
